pub fn is_source_mounted(path: &str, mounted_fs: &Filesystem) -> boolExpand description
Recursively check a given filesystem to see if it contains an already mounted source.
pub fn is_source_mounted(path: &str, mounted_fs: &Filesystem) -> boolRecursively check a given filesystem to see if it contains an already mounted source.